# Generated by roxygen2: do not edit by hand

S3method(corrected,ANOPAobject)
S3method(corrected,default)
S3method(explain,ANOPAobject)
S3method(explain,default)
S3method(print,ANOPAobject)
S3method(print,ANOPAtable)
S3method(summarize,ANOPAobject)
S3method(summarize,default)
S3method(summary,ANOPAobject)
S3method(uncorrected,ANOPAobject)
S3method(uncorrected,default)
export(A)
export(Atrans)
export(CI.Atrans)
export(CI.prop)
export(GRP)
export(SE.Atrans)
export(anopa)
export(anopaN2Power)
export(anopaPlot)
export(anopaPower2N)
export(anopaProp2fsq)
export(contrastProportions)
export(corrected)
export(emProportions)
export(explain)
export(posthocProportions)
export(prop)
export(rBernoulli)
export(summarize)
export(toCompiled)
export(toLong)
export(toWide)
export(uncorrected)
export(unitaryAlpha)
export(var.Atrans)
export(varA)
importFrom(Rdpack,reprompt)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,qchisq)
importFrom(stats,reshape)
importFrom(stats,runif)
importFrom(stats,var)
importFrom(superb,GRD)
importFrom(utils,capture.output)
importFrom(utils,combn)
